/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 * Copyright (C) 2022 Timm Fitschen <t.fitschen@indiscale
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */


DELIMITER //

DROP PROCEDURE IF EXISTS db_5_0.listFSODescriptorByParentDirectory //

/**
 * List the 

 *
 * Parameters
 * ----------
 * ParentDirectory : INT UNSIGNED
 *   The entity id of the parent directory.
 *
 * ResultSet
 * ---------
 * Tuples of (FileHashAlgo, FileId, FilePath, FileSize, FileHash,
 *            FileHashChecked, FileMimeType, FileStorageID, FileKey)
 */
CREATE PROCEDURE db_5_0.listFSODescriptorByParentDirectory(
    IN ParentDirectory INT UNSIGNED)
listFSODescriptorByParentDirectoryBody: BEGIN

    SELECT hash_algorithm AS FileHashAlgo,
            file_id AS FileId,
            parent_directory AS FileParentID,
            path AS FilePath,
            size AS FileSize,
            hex(hash) AS FileHash,
            checked_timestamp AS FileHashChecked,
            mimetype AS FileMimeType,
            file_storage_id AS FileStorageID,
            file_key AS FileKey
        FROM files
        WHERE parent_directory = ParentDirectory;

END;
//


DELIMITER ;
