/*
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2022 IndiScale GmbH <info@indiscale.com>
 * Copyright (C) 2022 Timm Fitschen <t.fitschen@indiscale
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */



DELIMITER //

DROP PROCEDURE IF EXISTS db_5_0.retrieveFSODescriptorByPath;

/**
 * Retrieve the VirtualFSODescriptor, i.e. only the id and special properties
 * of such an entity.
 *
 * Parameters
 * ----------
 * Path : VARCHAR(16000)
 *   The path of the FSO in the virtual file system.
 * 
 * Version
 *   The version id.  In this procedure only, the version may also be given as
 *   `HEAD` for the latest version or as `HEAD~n`, which retrieves the n-th
 *   ancestor of `HEAD`.
 *
 * ResultSet
 * ---------
 * Tuples of (FileHashAlgo, FileId, FilePath, FileSize, FileHash,
 *            FileHashChecked, FileMimeType, FileStorageID, FileKey)
 */
CREATE PROCEDURE db_5_0.retrieveFSODescriptorByPath(
    IN byPath VARBINARY(16000))
retrieveFSODescriptorByPathBody: BEGIN

    SELECT hash_algorithm AS FileHashAlgo,
            byPath as Param,
            (SELECT id FROM entity_ids WHERE internal_id = file_id) AS FileId,
            path AS FilePath,
            size AS FileSize,
            hex(hash) AS FileHash,
            checked_timestamp AS FileHashChecked,
            mimetype AS FileMimeType,
            file_storage_id AS FileStorageID,
            file_key AS FileKey
        FROM files
        WHERE path LIKE byPath;

END;
//


DELIMITER ;
